Learn R Programming

symptomcheckR (version 0.1.3)

get_ccs_by_triage: get_ccs_by_triage

Description

Calculates the Capability Comparison Score (CCS) for each symptom checker and each triage level

Usage

get_ccs_by_triage(data, correct, vignettes, apps, triagelevel)

Value

A data frame object containing the capability comparison score for each symptom checker on each triage level.

Arguments

data

A dataframe

correct

A string indicating the column name storing if the symptom checker solved the case (TRUE or FALSE)

vignettes

A string indicating the column name storing the vignette or vignette number

apps

A string indicating the column name storing the app names

triagelevel

A string indicating the column name storing the correct triage solutions

Examples

Run this code
data(symptomcheckRdata)
ccs <- get_ccs_by_triage(
  data = symptomcheckRdata,
  correct = "Correct_Triage_Advice_provided_from_app",
  vignettes = "Vignette_id",
  apps = "App_name",
  triagelevel = "Goldstandard_solution"
  )

Run the code above in your browser using DataLab